@@ -1,7 +1,7 @@
 package App::DuckPAN::Web;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.191';
+$App::DuckPAN::Web::VERSION = '0.192';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -293,8 +293,10 @@ sub request {
 		foreach my $result (@results) {
 
 			my $caller = $result->caller;
-			my $id = eval{ $caller->id };
-			push @ids, $id if $id;
+			#exlude parent/child IAs like CheatSheets
+			if(my $ia = DDG::Meta::Data->get_ia(module => $caller)){
+				push @ids, $ia->[0]{id} if @$ia == 1;
+			}
 
 			# Info for terminal.
 			p($result) if $result;
@@ -338,6 +340,7 @@ sub request {
 					# Inject a script which prints out what we want.
 					# There is no error-checking or support for non-auto-templates here.
 					my $structured = $result->structured_answer;
+					push @ids, $structured->{dynamic_id} if exists $structured->{dynamic_id};
 					if(exists $structured->{templates}){ # user-specified templates
 						push @calls_goodie, $structured;
 						last;
@@ -417,7 +420,7 @@ sub request {
 		#   calls_nrc : css calls
 		#   calls_template : handlebars templates
 
-		my $calls_nrj = join('', map{ DDG::Meta::Data->get_js($_) } @ids);
+		my $calls_nrj = join('', map{ DDG::Meta::Data->get_js(id => $_) } @ids);
 		my $calls_script = join('', map { q|<script type='text/JavaScript' src='| . $_ . q|'></script>| } @calls_script);
 		# For now we only allow a single goodie. If that changes, we will do the
 		# same join/map as with spices.
@@ -561,7 +564,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.191
+version 0.192
 
 =head1 AUTHOR
 
